<?php
/**
 * CPTUIEXT_Admin_About Class File.
 *
 * @package CPTUIExtended
 * @subpackage Admin
 * @author Pluginize
 * @since 1.0.0
 */

/**
 * Main initiation class.
 *
 * @internal
 *
 * @since 1.0.0
 */
class CPTUIEXT_Admin_About {

	/**
	 * Whether or not we have a new install.
	 *
	 * @var bool
	 * @since 1.4.0
	 */
	protected $is_new_install = false;

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		$this->is_new_install = isset( $_GET['is_new_install'] );
	}

	/**
	 * Initiate our hooks.
	 *
	 * @since 1.0.0
	 */
	public function hooks() {
		add_action( 'admin_init', array( $this, 'init' ) );
		add_action( 'cptui_extra_menu_items', array( $this, 'add_options_page' ), 10, 2 );
		add_action( 'admin_head', array( $this, 'admin_head' ) );
	}


	/**
	 * Register our setting to WP.
	 *
	 * @since 1.0.0
	 */
	public function init() {}

	/**
	 * Register our dashboard pages.
	 *
	 * @since 1.0.0
	 *
	 * @param string $parent_slug parent plugin menu.
	 * @param string $capability access.
	 */
	public function add_options_page( $parent_slug, $capability ) {

		add_dashboard_page(
			__( 'CPTUI Extended', 'cptuiext' ),
			__( 'CPTUI Extended', 'cptuiext' ),
			$capability,
			'cptui_about',
			[ $this, 'about_screen' ]
		);

		// Credits.
		add_dashboard_page(
			__( 'CPTUI Credits',  'cptuiext' ),
			__( 'CPTUI Credits',  'cptuiext' ),
			$capability,
			'cptui_credits',
			[ $this, 'credits_screen' ]
		);

		add_submenu_page( $parent_slug, esc_html__( 'CPTUI Extended', 'cptuiext' ), esc_html__( 'CPTUI Extended', 'cptuiext' ), $capability, 'cptui_about', [ $this, 'about_screen' ] );
	}

	/**
	 * Admin head.
	 *
	 * @since 1.0.0
	 */
	public function admin_head() {

		// About and Credits pages.
		remove_submenu_page( 'index.php', 'cptui_about' );
		remove_submenu_page( 'index.php', 'cptui_credits' );
	}

	/**
	 * Admin page markup. Mostly handled by CMB2.
	 *
	 * @since 1.0.0
	 */
	public function welcome_text() {
		?>
		<h1>
			<?php printf( esc_html__( 'Welcome to CPTUI Extended %s', 'cptuiext' ), cptui_extended()->version ); ?>
		</h1>

		<div class="about-text">
			<?php
			echo ( $this->is_new_install )
				? esc_html__( 'Way to level up with CPTUI Extended, which makes it simple for developers and non-developers alike to create an unlimited amount of custom post types.', 'cptuiext' )
				: esc_html__( 'Thank you for continuing to level up with the latest version of CPTUI Extended which makes it simple for developers and non-developers alike to create an unlimited amount of custom post types.', 'cptuiext' );
			?>
		</div>

		<div class="plugin-badge">
			<img src="<?php echo esc_url( cptui_extended()->url . 'assets/images/icon.png' ); ?>" alt="<?php esc_html_e( 'insert custom post type shortcodes.', 'cptuiext' ); ?>">
		</div>

		<?php

	}

	/**
	 * Display our about page.
	 *
	 * @since 1.0.0
	 */
	public function about_screen() {
	?>

		<div class="wrap about-wrap">

			<?php

			$this->welcome_text();
			$this->tab_navigation( __METHOD__ );
			if ( $this->is_new_install ) : ?>

				<div id="welcome-panel" class="welcome-panel">
					<div class="welcome-panel-content">
					</div>
				</div>

			<?php endif; ?>

			<div class="headline-feature">
				<div class="featured-image">
					<p><img src="<?php echo esc_url( cptui_extended()->url . 'assets/images/default-block-screenshot.png' ); ?>" alt="<?php esc_html_e( 'Screenshot of our first official WordPress block', 'cptuiext' ); ?>">
					</p>
				</div>
				<p class="introduction"><?php esc_html_e( 'CPTUI-Extended has finished migration into official block support.', 'cptuiext' ); ?>  </p>
				<p><?php esc_html_e( 'With CPTUI Extended 1.11.0, we finalized moving all of our current layouts into the CPTUI-Extended block, making it the preferred method to utilize the displaying power offered.', 'cptuiext' ); ?></p>
				<p><?php esc_html_e( 'All existing shortcodes should continue to work, but you no longer need to make use of the classic editor or classic editor block if you do not want to.', 'cptuiext' ); ?></p>
				<p><?php esc_html_e( 'This release added the Grid, Grid with Overlay, and Featured Plus blocks to finish things out.', 'cptuiext' ); ?></p>
				<p><?php esc_html_e( 'Another notable thing includes confirmed compatibility with the Full Site Editor capable TwentyTwentyTwo theme.', 'cptuiext' ); ?></p>
				<div class="clear"></div>
			</div>

			<hr />

			<div class="bp-features-section">
				<div class="feature-section two-col">
					<div>
						<h3 class="feature-title"><?php esc_html_e( 'Other miscellaneous items', 'cptuiext' ); ?></h3>
						<p><?php esc_html_e( 'Added title field output to some layouts that were missing the display.', 'cptuiext' ); ?></p>
						<p><?php esc_html_e( 'Code quality cleanup and behind-the-scenes restructuring,', 'cptuiext' ); ?></p>
					</div>
				</div>
			</div>

			<div class="changelog">
			</div>

			<p>
				<?php echo esc_html_x( 'Learn more:', 'About screen, website links', 'cptuiext' ); ?>
				<a href="https://pluginize.com/blog/">
					<?php echo esc_html_x( 'News', 'About screen, link to project blog', 'cptuiext' ); ?>
				</a> &bullet;
				<a href="http://docs.pluginize.com/">
					<?php echo esc_html_x( 'Documentation', 'About screen, link to documentation', 'cptuiext' ); ?>
				</a> &bullet;
				<a href="https://docs.pluginize.com/article/changelog/">
					<?php echo esc_html_x( 'Change log', 'cptuiext' ); ?>
				</a>
			</p>

			<p>
				<?php echo esc_html_x( 'Twitter:', 'official Twitter accounts:', 'cptuiext' ); ?>
				<a href="https://twitter.com/pluginize/">
					<?php echo esc_html_x( '@pluginize', '@pluginize twitter account name', 'cptuiext' ); ?>
				</a>
			</p>

		</div>

		<?php
	}

	/**
	 * Output our tab navigation.
	 *
	 * @since 1.0.0
	 *
	 * @param string $tab Active tab.
	 */
	public static function tab_navigation( $tab = 'whats_new' ) {
	?>

		<h2 class="nav-tab-wrapper">
			<a class="nav-tab <?php if ( 'CPTUIEXT_Admin_About::about_screen' === $tab ) : ?>nav-tab-active<?php endif; ?>" href="<?php echo esc_url( cptui_get_admin_url( add_query_arg( array( 'page' => 'cptui_about' ), 'index.php' ) ) ); ?>">
				<?php esc_html_e( 'What&#8217;s New', 'cptuiext' ); ?>
			</a><a class="nav-tab <?php if ( 'CPTUIEXT_Admin_About::credits_screen' === $tab ) : ?>nav-tab-active<?php endif; ?>" href="<?php echo esc_url( cptui_get_admin_url( add_query_arg( array( 'page' => 'cptui_credits' ), 'index.php' ) ) ); ?>">
				<?php esc_html_e( 'Credits', 'cptuiext' ); ?>
			</a>
		</h2>

	<?php
	}

	/**
	 * Display our credit screen.
	 *
	 * @since 1.0.0
	 */
	public function credits_screen() {
	?>

		<div class="wrap about-wrap">

			<?php $this->welcome_text(); ?>

			<?php $this->tab_navigation( __METHOD__ ); ?>

			<p class="about-description">
				<?php esc_html_e( 'Custom Post Types UI is created by a worldwide network of friendly folks like these.', 'cptuiext' ); ?>
			</p>

			<h3 class="wp-people-group">
				<?php esc_html_e( 'Plugin Contributors', 'cptuiext' ); ?>
			</h3>
			<?php
			$contributors = cptuiext_get_contributors();
			?>
			<ul class="wp-people-group " id="wp-people-group-project-contributors">

				<?php
				foreach ( $contributors as $contributor ) {
					printf(
						'<li class="wp-person" id="wp-person-%s"><a class="web" href="%s"><img alt="" class="gravatar" src="%s">%s</a><span class="title">%s</span></li>',
						$contributor['username'],
						$contributor['profile'],
						$contributor['gravatar'],
						$contributor['displayname'],
						$contributor['title']
					);
				}
				?>
			</ul>
			<h3 class="wp-people-group">
				<?php esc_html_e( 'Past Contributors', 'cptuiext' ); ?>
			</h3>
			<?php
			$past_contributors = cptuiext_get_past_contributors();
			?>
			<ul class="wp-people-group " id="wp-people-group-project-contributors">

				<?php
				foreach ( $past_contributors as $contributor ) {
					printf(
						'<li class="wp-person" id="wp-person-%s"><a class="web" href="%s"><img alt="" class="gravatar" src="%s">%s</a><span class="title">%s</span></li>',
						$contributor['username'],
						$contributor['profile'],
						$contributor['gravatar'],
						$contributor['displayname'],
						$contributor['title']
					);
				}
				?>
			</ul>
		</div>
		<?php
	}
}

/**
 * Return an array of contributors to CPTUI Extended.
 *
 * @since 1.4.0
 *
 * @return array
 */
function cptuiext_get_contributors() {
	return [
		[
			'username'    => 'pluginize',
			'profile'     => esc_attr( 'https://profiles.wordpress.org/pluginize/' ),
			'gravatar'    => esc_attr( '//www.gravatar.com/avatar/210484f55c0df074f663b2b6d082e063?s=60' ),
			'displayname' => 'Pluginize',
			'title'       => esc_html__( 'Contributor', 'cptuiext' ),
		],
		[
			'username'    => 'webdevstudios',
			'profile'     => esc_attr( 'https://profiles.wordpress.org/webdevstudios/' ),
			'gravatar'    => esc_attr( '//www.gravatar.com/avatar/2596fe59ce16cabfe5ddf5c7d734ef8a?s=60' ),
			'displayname' => 'WebDevStudios',
			'title'       => esc_html__( 'Contributor', 'cptuiext' ),
		],
		[
			'username'    => 'tw2113',
			'profile'     => esc_attr( 'https://profiles.wordpress.org/tw2113/' ),
			'gravatar'    => esc_attr( '//www.gravatar.com/avatar/a5d7c934621fa1c025b83ee79bc62366?s=60' ),
			'displayname' => 'Michael Beckwith',
			'title'       => esc_html__( 'Contributor', 'cptuiext' ),
		],
		[
			'username'    => 'williamsba1',
			'profile'     => esc_attr( 'https://profiles.wordpress.org/williamsba1/' ),
			'gravatar'    => esc_attr( '//www.gravatar.com/avatar/b3cd1f8ff494c64e64e1f8e23a8b75cf?s=60' ),
			'displayname' => 'Brad Williams',
			'title'       => esc_html__( 'Contributor', 'cptuiext' ),
		],
		[
			'username'    => 'iticiti',
			'profile'     => esc_attr( 'https://profiles.wordpress.org/iticiti/' ),
			'gravatar'    => esc_attr( '//www.gravatar.com/avatar/dbfeac3228643fd21e29084acafcbddf?s=60' ),
			'displayname' => 'Awais Altaf',
			'title'       => esc_html__( 'Contributor', 'cptuiext' ),
		],
		[
			'username'    => 'martyoconnor',
			'profile'     => esc_attr( 'https://profiles.wordpress.org/martyoconnor/' ),
			'gravatar'    => esc_attr( '//www.gravatar.com/avatar/f3bc16dc192c88cb37346ddfcdce07b8?s=60' ),
			'displayname' => 'Marty O\'Connor',
			'title'       => esc_html__( 'Contributor', 'cptuiext' ),
		],
	];
}

/**
 * Return an array of legacy contributors to CPTUI Extended.
 *
 * @return array
 * @since 1.8.0
 */
function cptuiext_get_past_contributors() {
	return [
		[
			'username'    => 'vegasgeek',
			'profile'     => esc_attr( 'https://profiles.wordpress.org/vegasgeek/' ),
			'gravatar'    => esc_attr( '//www.gravatar.com/avatar/6f3c8b1e3930788f8fc676c9f23769ac?s=60' ),
			'displayname' => 'John Hawkins',
			'title'       => esc_html__( 'Contributor', 'cptuiext' ),
		],
		[
			'username'    => 'colorful-tones',
			'profile'     => esc_attr( 'https://profiles.wordpress.org/colorful-tones/' ),
			'gravatar'    => esc_attr( '//www.gravatar.com/avatar/e3dd9f1bbd70a30a63d3d5cc6090059e?s=60' ),
			'displayname' => 'Damon Cook',
			'title'       => esc_html__( 'Contributor', 'cptuiext' ),
		],
		[
			'username'    => 'jomurgel',
			'profile'     => esc_attr( 'https://profiles.wordpress.org/jomurgel/' ),
			'gravatar'    => esc_attr( '//www.gravatar.com/avatar/3b3c904bdd9d088d72277bb7d26f4e2d?s=60' ),
			'displayname' => 'Jo Murgel',
			'title'       => esc_html__( 'Contributor', 'cptuiext' ),
		],
	];
}
