<?php
/**
 * CPTUIEXT_Network_Admin_UI Class File
 *
 * @package CPTUIExtended
 * @subpackage Admin
 * @author Pluginize
 * @since 1.0.0
 */

/**
 * Main initiation class
 *
 * @since  1.0.0
 */
class CPTUIEXT_Network_Admin_UI {

	/**
	 * Options Page title
	 *
	 * @var string
	 */
	protected $title = '';

	/**
	 * Options Page hook
	 *
	 * @var string
	 */
	protected $options_page = '';

	/**
	 * Parent plugin class
	 *
	 * @var   class
	 * @since NEXT
	 */
	protected $plugin = null;

	/**
	 * Holds an instance of the object
	 *
	 * @var CPTUIEXT_Network_Admin_UI
	 **/
	private static $instance = null;

	/**
	 * Constructor
	 *
	 * @since 1.0.0
	 * @param CPTUI_Extended $plugin this class.
	 */
	public function __construct( $plugin ) {
		$this->plugin = $plugin;
		$this->title = __( 'CPTUI Extended', 'cptuiext' );
	}

	/**
	 * Initiate our hooks
	 *
	 * @since 1.0.0
	 */
	public function hooks() {
		if ( function_exists( 'cptui_plugin_menu' ) ) {
			add_action( 'network_admin_menu', 'cptui_plugin_menu' );
		}
		add_action( 'network_admin_menu', [ $this, 'rename_menu_items' ] );
		add_action( 'network_admin_menu', [ $this, 'remove_menu_items' ], 999 );
	}

	/**
	 * Rename_menu_items
	 *
	 * @return void
	 */
	public function rename_menu_items() {
		global $menu;
		foreach ( $menu as $key => $value ) {
			if ( 'CPT UI' === $menu[ $key ][0] ) {
				$menu[ $key ][0] = $this->title;
				break;
			}
		}
	}

	/**
	 * Remove_menu_items
	 *
	 * @return void
	 */
	public function remove_menu_items() {
		remove_submenu_page( 'cptui_main_menu', 'cptui_support' );
		remove_submenu_page( 'cptui_main_menu', 'cptui_main_menu' );
	}

	/**
	 * Public getter method for retrieving protected/private variables
	 *
	 * @since 1.0.0
	 *
	 * @throws Exception If no valid field property provided.
	 *
	 * @param string $field Field to retrieve.
	 * @return mixed Field value or exception is thrown.
	 */
	public function __get( $field ) {
		// Allowed fields to retrieve.
		if ( in_array( $field, [ 'title', 'options_page' ], true ) ) {
			return $this->{$field};
		}

		throw new Exception( 'Invalid property: ' . $field );
	}
}

/**
 * Wrapper function around cmb2_get_option
 *
 * @since 1.0.0
 *
 * @param string $key Options array key.
 * @return mixed $value Option value
 */
function cptuiext_get_network_option( $key = '' ) {
	return cmb2_get_option( 'cptui_network_extended', $key );
}
