<?php
/**
 * CPTUIEXT Template Notices class file.
 * @author  Pluginize
 * @since   1.10.0
 * @package CPTUIExtended
 * @subpackage Template Notices
 */

/**
 * Class CPTUIEXT_Template_Notices
 * @since 1.10.0
 */
class CPTUIEXT_Template_Notices {

	public function hooks() {
		add_action( 'admin_notices', [ $this, 'template_version_notices' ] );
	}

	/**
	 * Display template version discrepencany notices.
	 * @return void
	 * @since   1.10.0
	 */
	public function template_version_notices() {

		$loader = new CPTUIEXT_Template_Loader();
		$paths = $loader->get_template_paths();

		$core_template_path = $paths[100];
		$custom_template_path = $paths[10];

		if ( ! is_dir( $custom_template_path ) ) {
			return;
		}

		$custom_template_parts = [];
		if ( $handle = opendir( $custom_template_path ) ) {
			while ( false !== ( $entry = readdir( $handle ) ) ) {
				if ( $entry != "." && $entry != ".." ) {
					$custom_template_parts[] = $entry;
				}
			}
			closedir( $handle );
		}

		if ( empty( $custom_template_parts ) ) {
			return;
		}

		$core_template_versions = [];
		$custom_template_versions = [];
		foreach ( $custom_template_parts as $filename ) {
			$core_template_versions[ $filename ] = $loader->get_template_version( $core_template_path . $filename );
			$custom_template_versions[ $filename ] = $loader->get_template_version( $custom_template_path . $filename );
		}

		foreach ( $custom_template_versions as $filename => $file_version ) {
			// Error if versions do not match, or custom template version unknown.
			if ( version_compare( $file_version, $core_template_versions[ $filename ], '!=' ) ) {
				$error_notices[] = sprintf(
				/* translators: placeholder 1 is template filename, placeholder 2 is custom template version, placeholder 3 is core template version. */
					esc_html__(
						'Your customized CPTUI Extended template, %1$s, version %2$s is out of date and may need updated. The core version is %3$s. Reach out to Pluginize support for any questions.',
						'cptuiext'
					),
					$filename,
					! empty( $file_version ) ? $file_version : esc_html__( 'unknown', 'cptuiext' ),
					$core_template_versions[ $filename ]
				);
			}
		}

		if ( empty( $error_notices ) ) {
			return;
		}

		$output = '';
		foreach ( $error_notices as $error_notice ) {
			$output .= wp_get_admin_notice(
				$error_notice,
				[
					'type' => 'error',
				]
			);
		}
		echo wp_kses_post( $output );
	}
}
