<?php
/**
 * CPTUI Extended Shortcode Functions.
 * @package    CPTUIExtended
 * @subpackage Loader
 * @author     Pluginize
 * @since      1.11.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Returns parsed post query args.
 *
 * @param string $attributes shortcode attributes.
 *
 * @return array parsed post query.
 */
function cptui_filter_query( $attributes ) {

	/**
	 * Filters WP_Query for a shortrcode.
	 *
	 * @param array $args       post query args.
	 * @param array $attributes shortcode attributes.
	 */
	return apply_filters( 'cptui_filter_query', [], $attributes );
}

/**
 * Filter WP_Query with shortcode data
 *
 * @param array $args       post query arguments.
 * @param array $attributes shortcode attributes.
 *
 * @return array parsed post query.
 * @internal
 */
function cptui_filter_shortcode_query( $args, $attributes ) {

	$paged = isset( $_GET[ $attributes['cptui_shortcode_id'] . '-page' ] ) ? esc_attr( $_GET[ $attributes['cptui_shortcode_id'] . '-page' ] ) : 1;

	switch ( $attributes['cptui_shortcode'] ) {
		case 'default_shortcode':

			$args['post_type'] = isset( $attributes['cptui_posttype'] ) ? $attributes['cptui_posttype'] : 'post';

			if ( isset( $attributes['attached_post'] ) && '' !== $attributes['attached_post'] ) {
				$args['post__in'] = explode( ',', $attributes['attached_post'] );
			}

			$args['posts_per_page'] = isset( $attributes['amount'] ) ? esc_attr( $attributes['amount'] ) : '';
			$args['paged']          = $paged;

			break;
		case 'grid_with_overlay_shortcode':

			$args['post_type'] = isset( $attributes['cptui_posttype'] ) ? $attributes['cptui_posttype'] : 'post';

			if ( isset( $attributes['attached_post'] ) && '' !== $attributes['attached_post'] ) {
				$args['post__in'] = explode( ',', $attributes['attached_post'] );
			}

			// Have grid with overlay layout default to 5 instead of WP_Query default of Settings > Reading or 10.
			$args['posts_per_page'] = isset( $attributes['amount'] ) ? esc_attr( $attributes['amount'] ) : 5;

			break;
		case 'single_post_shortcode':

			if ( isset( $attributes['post_id'] ) ) {
				$args['p'] = $attributes['post_id'];
			}

			break;
		case 'single_page_shortcode':

			if ( isset( $attributes['page_id'] ) ) {
				$args['page_id'] = $attributes['page_id'];
			}

			break;
		case 'featured_plus_shortcode':

			$args['post_type'] = isset( $attributes['cptui_posttype'] ) ? $attributes['cptui_posttype'] : 'post';

			if ( isset( $attributes['featured_plus_type'] ) && 'top' === $attributes['featured_plus_type'] ) {
				$args['posts_per_page'] = isset( $attributes['amount'] ) ? esc_attr( $attributes['amount'] ) : 5;
			} else {
				$args['posts_per_page'] = '4';
			}

			$args['paged'] = $paged;

			break;
		case 'single_post_type_shortcode':

			if ( isset( $attributes['post_id'] ) ) {
				$args['p'] = $attributes['post_id'];
			}

			if ( isset( $attributes['cptui_posttype'] ) ) {
				$args['post_type'] = $attributes['cptui_posttype'];
			}

			break;
		case 'list_shortcode':

			$args['post_type'] = isset( $attributes['cptui_posttype'] ) ? $attributes['cptui_posttype'] : 'post';

			if ( isset( $attributes['attached_post'] ) && '' !== $attributes['attached_post'] ) {
				$args['post__in'] = explode( ',', $attributes['attached_post'] );
			}

			if ( isset( $attributes['amount'] ) && '' !== $attributes['amount'] && isset( $attributes['attached_post'] ) && '' === $attributes['attached_post'] ) {
				$args['posts_per_page'] = $attributes['amount'];
			}

			break;
		case 'grid_shortcode':

			$args['post_type']      = isset( $attributes['cptui_posttype'] ) ? $attributes['cptui_posttype'] : 'post';
			$args['posts_per_page'] = isset( $attributes['amount'] ) ? esc_attr( $attributes['amount'] ) : '5';

			if ( isset( $attributes['attached_post'] ) && '' !== $attributes['attached_post'] ) {
				$args['post__in'] = explode( ',', $attributes['attached_post'] );
			}

			$args['paged'] = $paged;

			break;
		case 'woo_product_shortcode':

			if ( isset( $attributes['attached_product'] ) ) {
				$args['post_type'] = 'product';

				if ( isset( $attributes['attached_product'] ) && '' !== $attributes['attached_product'] ) {
					$args['post__in'] = explode( ',', $attributes['attached_product'] );
				}
			}

			$args['paged'] = $paged;

			break;
		case 'post_cards_shortcode':

			$args['post_type']      = isset( $attributes['cptui_posttype'] ) ? $attributes['cptui_posttype'] : 'post';
			$args['posts_per_page'] = isset( $attributes['amount'] ) ? esc_attr( $attributes['amount'] ) : '';

			if ( isset( $attributes['attached_post'] ) && '' !== $attributes['attached_post'] ) {
				$args['post__in'] = explode( ',', $attributes['attached_post'] );
			}

			$args['paged'] = $paged;

			break;
		case 'edd_download_shortcode':

			if ( isset( $attributes['attached_download'] ) ) {
				$args['post_type'] = 'download';

				if ( '' !== $attributes['attached_download'] ) {
					$args['post__in'] = explode( ',', $attributes['attached_download'] );
				}
			}

			$args['paged'] = $paged;

			break;
		case 'slider_shortcode':

			$args['post_type'] = isset( $attributes['cptui_posttype'] ) ? $attributes['cptui_posttype'] : 'post';

			if ( isset( $attributes['attached_post'] ) ) {
				if ( '' !== $attributes['attached_post'] ) {
					$args['post__in'] = explode( ',', $attributes['attached_post'] );
				}
			}

			$args['posts_per_page'] = isset( $attributes['amount'] ) ? esc_attr( $attributes['amount'] ) : '';

			break;
	}

	$args['ignore_sticky_posts'] = true;

	if ( isset( $attributes['order_by'] ) && 'none' !== $attributes['order_by'] ) {
		$args['orderby'] = $attributes['order_by'];
	}
	if ( isset( $attributes['order'] ) && 'DESC' !== $attributes['order'] ) {
		$args['order'] = $attributes['order'];
	}

	if ( isset( $attributes['tax_query'] ) && '' !== $attributes['tax_query'] ) {
		$args['tax_query'] = $attributes['tax_query'];
	}

	if ( isset( $attributes['tax_query'] ) && '' !== $attributes['tax_query'] ) {
		$args['tax_query'] = $attributes['tax_query'];
	}

	return $args;
}
add_filter( 'cptui_filter_query', 'cptui_filter_shortcode_query', 10, 2 );

/**
 * Returns parsed shortcode attributes array.
 *
 * @param string $attributes shortcode attributes.
 *
 * @return array parsed attributes array.
 */
function cptui_shortcode_atts( $attributes ) {
	/**
	 * Filters shortcode atrributes.
	 *
	 * @param array $attributes shortcode attributes.
	 */
	return apply_filters( 'cptui_shortcode_atts', $attributes );
}

/**
 * Filters cmb2 search posts field query for published content.
 *
 * @param object $query pre get post object.
 *
 * @return void
 */
function cptui_filter_search_post_query( $query ) {
	$query->set( 'post_status', [ 'publish' ] );
}

add_action( 'search_set_post_type', 'cptui_filter_search_post_query' );
