<?php

/**
 * Display dropdown for choosen which taxonomy term to filter post type list by based on CPTUI settings.
 *
 * @param string $post_type Post type being displayed in admin.
 * @param string $which     Whether we're in the top or bottom area of List Table.
 *
 * @since 1.12.0
 */
function cptuiext_filter_post_type_by_taxonomy_display( $post_type, $which ) {

	// Current taxonomies on the post type being displayed.
	$associated_taxonomies = get_object_taxonomies( $post_type );
	// All of the taxonomies registered in CPTUI
	$cptui_taxonomies = cptui_get_taxonomy_data();
	// All of the taxonomy slugs registered in CPTUI
	$cptui_taxonomies_keys = array_keys( $cptui_taxonomies );
	// If the current post type doesn't have one of the CPTUI taxonomies, return early
	$matched_taxonomies = array_intersect( $cptui_taxonomies_keys, $associated_taxonomies );

	if ( empty( $matched_taxonomies ) ) {
		return;
	}

	$should_filter        = false;
	$taxonomies_to_filter = [];
	foreach ( $cptui_taxonomies as $taxonomy ) {
		if ( isset( $taxonomy['tax_filter_post_types'] ) && '1' === $taxonomy['tax_filter_post_types'][0] ) {
			$should_filter          = true;
			$taxonomies_to_filter[] = $taxonomy['name'];
		}
	}

	if ( ! $should_filter ) {
		return;
	}

	global $wp_query;
	foreach ( $taxonomies_to_filter as $taxonomy_filter ) {
		$show_option_all_text = sprintf(
			esc_html__( 'Show all %s', 'cptuiext' ),
			$cptui_taxonomies[ $taxonomy_filter ]['label']
		);
		wp_dropdown_categories( [
			'show_option_all' => $show_option_all_text,
			'taxonomy'        => $taxonomy_filter,
			'name'            => $taxonomy_filter,
			'orderby'         => 'name',
			'selected'        => $wp_query->query[ $taxonomy_filter ] ?? '',
			'hierarchical'    => false,
			'depth'           => 3,
			'show_count'      => false,
			'hide_empty'      => true,
			'hide_if_empty'   => true,
		] );
	}
}
add_action( 'restrict_manage_posts', 'cptuiext_filter_post_type_by_taxonomy_display', 10, 2 );

/**
 * Add in selected query variables into our query.
 *
 * @param WP_Query $query The current query being made.
 *
 * @since 1.12.0
 */
function cptuiext_do_filter_post_type_by_taxonomy( $query ) {
	if ( ! $query->is_main_query() ) {
		return;
	}

	if ( ! is_admin() ) {
		return;
	}

	// ampersand is important.
	$qv = &$query->query_vars;

	$cptui_taxonomies     = cptui_get_taxonomy_data();
	$taxonomies_to_filter = [];
	foreach ( $cptui_taxonomies as $taxonomy ) {
		if ( isset( $taxonomy['tax_filter_post_types'] ) && '1' === $taxonomy['tax_filter_post_types'][0] ) {
			$taxonomies_to_filter[] = $taxonomy['name'];
		}
	}

	foreach ( $taxonomies_to_filter as $taxonomy_slug ) {
		if (
			! empty( $qv[ $taxonomy_slug ] ) &&
			is_numeric( $qv[ $taxonomy_slug ] )
		) {
			$term                 = get_term_by( 'id', $qv[ $taxonomy_slug ], $taxonomy_slug );
			$qv[ $taxonomy_slug ] = $term->slug;
		}
	}
}
add_filter( 'parse_query', 'cptuiext_do_filter_post_type_by_taxonomy' );
