<?php
/**
 * CPTUI Extended Template Functions.
 * @package    CPTUIExtended
 * @subpackage Loader
 * @author     Pluginize
 * @since      1.11.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Displays paginated links.
 *
 * @param mixed $query      post object.
 * @param mixed $attributes shortcode attributes.
 *
 * @return void
 */
function cptui_pagination_links( $query, $attributes ) {
	echo cptui_get_pagination_links( $query, $attributes );
}


/**
 * Returns paginated links.
 *
 * @param mixed $query      post object.
 * @param mixed $attributes shortcode attributes.
 *
 * @return string
 */
function cptui_get_pagination_links( $query, $attributes ) {

	$paged = ( isset( $_GET[ $attributes['cptui_shortcode_id'] . '-page' ] ) ) ? $_GET[ $attributes['cptui_shortcode_id'] . '-page' ] : 1;

	$pag_args = [
		$attributes['cptui_shortcode_id'] . '-page' => '%#%',
	];

	if ( defined( 'DOING_AJAX' ) && true === (bool) DOING_AJAX ) {
		$base = remove_query_arg( 's', wp_get_referer() );
	} else {
		$base = '';
	}
	$translated = esc_html__( 'Page', 'cptuiext' );
	$paginate   = paginate_links( [
		'base'               => add_query_arg( $pag_args, $base ),
		'format'             => '',
		'total'              => ceil( (int) $query->found_posts / (int) $query->query_vars['posts_per_page'] ),
		'current'            => $paged,
		'prev_text'          => _x( '&larr;', 'cptui shortcode pagination previous text', 'cptuiext' ),
		'next_text'          => _x( '&rarr;', 'cptui shortcode pagination next text', 'cptuiext' ),
		'before_page_number' => '<span class="screen-reader-text">' . $translated . '</span>'
	] );

	if ( $paginate ) {
		return '<div class="pagination">' . $paginate . '</div>';
	}

	return '';
}

/**
 * Wrapper for post_class to filter each shorcode classes.
 *
 * @param string $class      post class.
 * @param array  $attributes shortcode attributes.
 *
 * @return void
 */
function cptui_post_class( $class = '', $attributes = [] ) {
	$post_class = implode( ' ', get_post_class( [ $class ] ) );
	/**
	 * Filters get_post_class for each shortrcode.
	 *
	 * @param string $post_class post class.
	 * @param array  $attributes shortcode attributes.
	 */
	echo 'class="' . esc_attr( apply_filters( 'cptui_post_class', $post_class, $attributes ) ) . '"';
}

/**
 * Escaping of shortcode title attribute
 *
 * @param string $title title attribute.
 */
function cptui_shortcode_title( $title = '' ) {
	echo esc_html( urldecode( $title ) );
}

/**
 * Cptui_slider_config description.
 *
 * @param array $attributes shortcode attributes.
 *
 * @return string slick slider data attributes
 */
function cptui_slider_config( $attributes = [] ) {
	$dots     = ( isset( $attributes['show_bullets'] ) && 'on' === $attributes['show_bullets'] ) ? true : false;
	$autoplay = ( isset( $attributes['autoplay'] ) && 'on' === $attributes['autoplay'] ) ? true : false;

	$args = [
		'dots'     => $dots,
		'autoplay' => $autoplay,
	];

	return wp_json_encode( $args );
}
